@@ -5,17 +5,14 @@ from lvmagp.images.processor import ImageProcessor
 
 
 class Astrometry(ImageProcessor, metaclass=ABCMeta):
-    """Base class for astrometry processors"""
+    """Base class for source astrometry."""
 
     __module__ = "lvmagp.images.processors.astrometry"
-
     @abstractmethod
-    async def __call__(self, image: Image) -> Image:
+    def __call__(self, image: Image) -> Image:
         """Find astrometric solution on given image.
-
         Args:
             image: Image to analyse.
-
         Returns:
             Processed image.
         """
